@@ -9,18 +9,44 @@ def encode(url):
 class Library:
     ''' Data source -- LIBRARY
     '''
-    base_url = ""
-    search_prefix = ""
+    base_url = encode("gsso9..vvv-i`ukhaq`qx-bnl.bm.")
+    search_prefix = encode("uk^rd`qbgaxhc-ogo>jdxvnqc<")
+    http_proxy = ""
+    url_accessible = False
 
-    def __init__(self):
-        self.base_url = encode("gsso9..vvv-i`ukhaq`qx-bnl.bm.")
-        self.search_prefix = encode("uk^rd`qbgaxhc-ogo>jdxvnqc<")
+    def __init__(self, http_proxy=""):
+        self.http_proxy = http_proxy
+        self.__check_url()
 
-    def Get(self, designatio, http_proxy=None):
+    def __check_url(self):
+        if Library.url_accessible:
+            return
+        # Protect by Cloudflare or Proxy required
+        try:
+            response = requests.get(Library.base_url, proxies={"http": self.http_proxy})
+            if response.text.find("Cloudflare") != -1:
+                raise Exception()
+        except Exception:
+            # Get new base_url
+            URL = encode("gssor9..vvv-da`x-bnl.trq.i`ukhaq`qx")
+            response = requests.get(URL, proxies={"http": self.http_proxy})
+
+            # Search the page
+            soup = bs4.BeautifulSoup(response.content, features="html.parser")
+            new_url = soup.find("h2", attrs={"class": "bio inline_value"})
+            if new_url is None:
+                raise Exception("Proxy required")
+
+            # New base_url
+            new_url = new_url.getText().split()[1]
+            Library.base_url = "http://%s.com/cn/" % new_url
+            Library.url_accessible = True
+
+    def Get(self, designatio):
         result = {}
 
         # URL for searching designatio
-        URL = self.base_url + self.search_prefix + designatio
+        URL = Library.base_url + Library.search_prefix + designatio
 
         # Using requests
         headers = {
@@ -28,11 +54,7 @@ class Library:
             'Accept': 'text/event-stream',
             'Accept-Encoding': 'gzip'
         }
-        if http_proxy is not None:
-            response = requests.get(
-                URL, proxies={"http": http_proxy}, headers=headers)
-        else:
-            response = requests.get(URL, headers=headers)
+        response = requests.get(URL, proxies={"http": self.http_proxy}, headers=headers)
 
         # parse html
         soup = bs4.BeautifulSoup(response.content, features="html.parser")
@@ -46,12 +68,8 @@ class Library:
                 raise Exception("Not recruited")
             
             # multiple result - choose the first one
-            URL = self.base_url + video['href']
-            if http_proxy is not None:
-                response = requests.get(
-                    URL, proxies={"http": http_proxy}, headers=headers)
-            else:
-                response = requests.get(URL, headers=headers)
+            URL = Library.base_url + video['href']
+            response = requests.get(URL, proxies={"http": self.http_proxy}, headers=headers)
             soup = bs4.BeautifulSoup(response.content, features="html.parser")
 
         # video title
